@@ -12,8 +12,8 @@ ENVIO_PRAXIS_NS = 'http://www.praxis.com.mx/EnvioCda/'
 class CDA(BaseModel):
     id: int
     mensaje_id: int
-    op_fecha_oper: int
-    op_hora_abono: int
+    op_fecha_oper: str
+    op_hora_abono: str
     op_cve_rastreo: str
 
     op_clave_emisor: str
@@ -53,15 +53,14 @@ class CDA(BaseModel):
             nsmap={'env': ENVIO_PRAXIS_NS},
         )
 
-        elements = self.dict(exclude={'id', 'mensaje_id'})
+        elements = self.dict(exclude_none=True, exclude={'id', 'mensaje_id'})
 
         for element, value in elements.items():  # noqa: WPS110
             if element in self.__fields__:
                 upper_camel_case_element = to_upper_camel_case(element)
-                subelement = etree.SubElement(mensaje, etree.QName(ENVIO_PRAXIS_NS, upper_camel_case_element))
+                subelement = etree.SubElement(mensaje, etree.QName(ENVIO_PRAXIS_NS, upper_camel_case_element))  # noqa: E501
                 subelement.text = str(value)
 
-        print(etree.tostring(mensaje))
         return mensaje
 
     @classmethod
